==> jc-1.4.0.tar.gz: org/ietf/jgss/GSSName.h <==
// public abstract interface org.ietf.jgss.GSSName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb9178e39855b48e org_ietf_jgss_GSSName

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_ietf_jgss_GSSName_H_
#define _JC_org_ietf_jgss_GSSName_H_

// Typedefs
typedef struct _jc_org_ietf_jgss_GSSName$fields_struct	_jc_org_ietf_jgss_GSSName$fields_struct;
typedef const struct _jc_org_ietf_jgss_GSSName$vtype	_jc_org_ietf_jgss_GSSName$vtype;

// Class fields structure
struct _jc_org_ietf_jgss_GSSName$fields_struct {
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fANONYMOUS;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fEXPORT__5fNAME;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fHOSTBASED__5fSERVICE;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fMACHINE__5fUID__5fNAME;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fSTRING__5fUID__5fNAME;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fUSER__5fNAME;
};
extern _jc_org_ietf_jgss_GSSName$fields_struct _jc_org_ietf_jgss_GSSName$class_fields;

// Static methods
extern void _jc_org_ietf_jgss_GSSName$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_org_ietf_jgss_GSSName$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_org_ietf_jgss_GSSName$vtype _jc_org_ietf_jgss_GSSName$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_ietf_jgss_GSSName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_ietf_jgss_GSSName$class_object;

#endif	/* _JC_org_ietf_jgss_GSSName_H_ */

==> jc-1.4.6.tar.gz: org/ietf/jgss/GSSName.h <==
// public abstract interface org.ietf.jgss.GSSName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fb9178e39855b48e org_ietf_jgss_GSSName

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_ietf_jgss_GSSName_H_
#define _JC_org_ietf_jgss_GSSName_H_

// Typedefs
typedef struct _jc_org_ietf_jgss_GSSName$fields_struct	_jc_org_ietf_jgss_GSSName$fields_struct;
typedef const struct _jc_org_ietf_jgss_GSSName$vtype	_jc_org_ietf_jgss_GSSName$vtype;

// Class fields structure
struct _jc_org_ietf_jgss_GSSName$fields_struct {
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fANONYMOUS;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fEXPORT__5fNAME;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fHOSTBASED__5fSERVICE;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fMACHINE__5fUID__5fNAME;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fSTRING__5fUID__5fNAME;
	struct _jc_org_ietf_jgss_Oid$object	*NT__5fUSER__5fNAME;
};
extern _jc_org_ietf_jgss_GSSName$fields_struct _jc_org_ietf_jgss_GSSName$class_fields;

// Static methods
extern void _jc_org_ietf_jgss_GSSName$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_org_ietf_jgss_GSSName$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_org_ietf_jgss_GSSName$vtype _jc_org_ietf_jgss_GSSName$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_ietf_jgss_GSSName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_ietf_jgss_GSSName$class_object;

#endif	/* _JC_org_ietf_jgss_GSSName_H_ */
